@@ -13,6 +13,7 @@ RE_CHARACTER_GAP = fr'\[{CA}\.{NUM}\]'
 RE_LINE_GAP      = fr'lost\.{CA_DOT}{NUM}lin'
 RE_SPACE         = fr'vac\.{CA_DOT}{NUM}{LINE}'
 
+RE_SUPPLIED = r'\[(.+?)\]'
 
 def _handle_ca(ca, el):
     if ca:
@@ -60,3 +61,12 @@ class SpaceProcessor(InlineProcessor):
         el.set('unit', 'line' if lin else 'character')
         _handle_ca(ca, el)
         return el, m.start(), m.end()
+
+
+class SuppliedProcessor(InlineProcessor):
+
+    def handleMatch(self, m, data):
+        el = etree.Element('suppied')
+        el.set('reason', 'lost')
+        el.text = m.group(1)
+        return el, m.start(), m.end()
